@@ -76,12 +76,7 @@ PdfPlug::PdfPlug(ScribusDoc* doc, int flags)
 
 QImage PdfPlug::readThumbnail(const QString& fName)
 {
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 83, 0)
 	globalParams.reset(new GlobalParams());
-#else
-	std::unique_ptr<GlobalParams> globalParamsPtr(new GlobalParams());
-	globalParams = globalParamsPtr.get();
-#endif
 	globalParams->setErrQuiet(true);
 
 	QString pdfFile = QDir::toNativeSeparators(fName);
@@ -105,7 +100,11 @@ QImage PdfPlug::readThumbnail(const QString& fName)
 	bgColor[0] = 255;
 	bgColor[1] = 255;
 	bgColor[2] = 255;
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(26, 2, 0)
+	SplashOutputDev dev(splashModeXBGR8, 4, bgColor, true);
+#else
 	SplashOutputDev dev(splashModeXBGR8, 4, false, bgColor, true);
+#endif
 	dev.setVectorAntialias(true);
 	dev.setFreeTypeHinting(true, false);
 	dev.startDoc(&pdfDoc);
@@ -137,7 +136,7 @@ QImage PdfPlug::readThumbnail(const QString& fName)
 	return image;
 }
 
-bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 #ifdef Q_OS_MACOS
 	showProgress = false;
@@ -168,7 +167,7 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_progressDialog->setProgress("GI", 0);
 		m_progressDialog->show();
 		connect(m_progressDialog, SIGNAL(canceled()), this, SLOT(cancelRequested()));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	else
 		m_progressDialog = nullptr;
@@ -176,27 +175,24 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	if (m_progressDialog)
 	{
 		m_progressDialog->setOverallProgress(1);
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	double docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
 	double docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
-	if (!m_interactive || (flags & LoadSavePlugin::lfInsertPage))
+	if (m_Doc && (!m_interactive || (flags & LoadSavePlugin::lfInsertPage)))
 	{
 		m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
 		m_Doc->addPage(0);
 		m_Doc->view()->addPage(0, true);
 	}
-	else
+	else if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
 	{
-		if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
-		{
-			m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, 0, 0, 0, 0, 1, "Custom", true);
-			ScCore->primaryMainWindow()->HaveNewDoc();
-			ret = true;
-		}
+		m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, 0, 0, 0, 0, 1, "Custom", true);
+		ScCore->primaryMainWindow()->HaveNewDoc();
+		ret = true;
 	}
 
-	if ((ret) || (!m_interactive))
+	if (ret || !m_interactive)
 	{
 		if (docWidth > docHeight)
 			m_Doc->setPageOrientation(1);
@@ -212,7 +208,7 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
 		m_Doc->view()->updatesOn(false);
 	m_Doc->scMW()->setScriptRunning(true);
-	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
 	if (convert(fNameIn))
@@ -233,8 +229,8 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if ((m_elements.count() > 0) && (!ret) && (m_interactive))
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		if (!m_elements.isEmpty() && !ret && m_interactive)
 		{
 			if (flags & LoadSavePlugin::lfScripted)
 			{
@@ -295,7 +291,7 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->scMW()->setScriptRunning(false);
 		if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 			m_Doc->view()->updatesOn(true);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		success = false;
 	}
 	if (m_interactive)
@@ -303,10 +299,10 @@ bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	//CB If we have a gui we must refresh it if we have used the progressbar
 	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 	{
-		if ((showProgress) && (!m_interactive))
+		if (showProgress && !m_interactive)
 			m_Doc->view()->DrawNew();
 	}
-	qApp->restoreOverrideCursor();
+	QApplication::restoreOverrideCursor();
 	return success;
 }
 
@@ -328,15 +324,10 @@ bool PdfPlug::convert(const QString& fn)
 		m_progressDialog->setOverallProgress(2);
 		m_progressDialog->setLabel("GI", tr("Generating Items"));
 		m_progressDialog->setBusyIndicator("GI");
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 83, 0)
 	globalParams.reset(new GlobalParams());
-#else
-	std::unique_ptr<GlobalParams> globalParamsPtr(new GlobalParams());
-	globalParams = globalParamsPtr.get();
-#endif
 	globalParams->setErrQuiet(true);
 
 	QList<OptionalContentGroup*> ocgGroups;
@@ -355,7 +346,7 @@ bool PdfPlug::convert(const QString& fn)
 			pdfDoc = nullptr;
 			if (m_progressDialog)
 				m_progressDialog->hide();
-			qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+			QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 			ScribusMainWindow* mw = m_Doc->scMW();
 			bool ok;
 			QString text = QInputDialog::getText(mw, tr("Open PDF-File"), tr("Password"), QLineEdit::Normal, "", &ok);
@@ -370,15 +361,12 @@ bool PdfPlug::convert(const QString& fn)
 				auto userPW = new GooString(text.toLocal8Bit().data());
 				pdfDoc.reset(new PDFDoc(fname, userPW, userPW, nullptr));
 #endif
-				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 			}
 			if ((!pdfDoc) || (pdfDoc->getErrorCode() != errNone))
 			{
 				if (m_progressDialog)
 					m_progressDialog->close();
-#if POPPLER_ENCODED_VERSION < POPPLER_VERSION_ENCODE(0, 83, 0)
-				delete globalParams;
-#endif
 				return false;
 			}
 			if (m_progressDialog)
@@ -414,7 +402,7 @@ bool PdfPlug::convert(const QString& fn)
 			{
 				if (m_progressDialog)
 					m_progressDialog->hide();
-				qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 				PdfImportOptions optImp(ScCore->primaryMainWindow());
 				QFileInfo fi(fn);
 				optImp.setUpOptions(fi.fileName(), firstPage, lastPage, m_interactive, boxesAreDifferent, this);
@@ -437,7 +425,7 @@ bool PdfPlug::convert(const QString& fn)
 					useMediaBox = false;
 				if (cropped)
 					useMediaBox = true;
-				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 				if (m_progressDialog)
 					m_progressDialog->show();
 			}
@@ -446,7 +434,7 @@ bool PdfPlug::convert(const QString& fn)
 			if (m_progressDialog)
 			{
 				m_progressDialog->setTotalSteps("GI", pageNs.size());
-				qApp->processEvents();
+				QApplication::processEvents();
 			}
 			if (pageNs.size() <= 0) {
 				m_pdfDoc = nullptr;
@@ -555,22 +543,22 @@ bool PdfPlug::convert(const QString& fn)
 					{
 						Object obj;
 						Dict *infoDict = info.getDict();
-						obj = infoDict->lookup((char*) "Title");
+						obj = infoDict->lookup("Title");
 						if (obj.isString())
 						{
 							m_Doc->documentInfo().setTitle(UnicodeParsedString(obj.getString()));
 						}
-						obj = infoDict->lookup((char*) "Author");
+						obj = infoDict->lookup("Author");
 						if (obj.isString())
 						{
 							m_Doc->documentInfo().setAuthor(UnicodeParsedString(obj.getString()));
 						}
-						obj = infoDict->lookup((char*) "Subject");
+						obj = infoDict->lookup("Subject");
 						if (obj.isString())
 						{
 							m_Doc->documentInfo().setSubject(UnicodeParsedString(obj.getString()));
 						}
-						obj = infoDict->lookup((char*) "Keywords");
+						obj = infoDict->lookup("Keywords");
 						if (obj.isString())
 						{
 							//		s1 = obj.getString();
@@ -613,7 +601,7 @@ bool PdfPlug::convert(const QString& fn)
 						if (m_progressDialog)
 						{
 							m_progressDialog->setProgress("GI", i);
-							qApp->processEvents();
+							QApplication::processEvents();
 						}
 						int pp = pageNs[i];
 						m_Doc->setActiveLayer(baseLayer);
@@ -827,16 +815,12 @@ bool PdfPlug::convert(const QString& fn)
 		}
 		pdfDoc.reset();
 	}
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 83, 0)
 	globalParams.reset();
-#else
-	globalParams = nullptr;
-#endif
 
 //	qDebug() << "converting finished";
 //	qDebug() << "Imported" << m_elements.count() << "Elements";
 
-	if (m_elements.count() == 0)
+	if (m_elements.isEmpty())
 	{
 		for (int i = 0; i < m_importedColors.count(); i++)
 		{
@@ -863,11 +847,15 @@ QImage PdfPlug::readPreview(int pgNum, int width, int height, int box)
 	bgColor[0] = 255;
 	bgColor[1] = 255;
 	bgColor[2] = 255;
-	SplashOutputDev *dev = new SplashOutputDev(splashModeXBGR8, 4, false, bgColor, true);
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(26, 2, 0)
+	auto dev = std::make_unique<SplashOutputDev>(splashModeXBGR8, 4, bgColor, true);
+#else
+	auto dev = std::make_unique<SplashOutputDev>(splashModeXBGR8, 4, false, bgColor, true);
+#endif
 	dev->setVectorAntialias(true);
 	dev->setFreeTypeHinting(true, false);
 	dev->startDoc(m_pdfDoc);
-	m_pdfDoc->displayPage(dev, pgNum, hDPI, vDPI, 0, true, false, false);
+	m_pdfDoc->displayPage(dev.get(), pgNum, hDPI, vDPI, 0, true, false, false);
 	SplashBitmap *bitmap = dev->getBitmap();
 	int bw = bitmap->getWidth();
 	int bh = bitmap->getHeight();
@@ -905,7 +893,6 @@ QImage PdfPlug::readPreview(int pgNum, int width, int height, int box)
 		pp.drawRect(cRect);
 		pp.end();
 	}
-	delete dev;
 	return image;
 }
 
@@ -926,10 +913,10 @@ QRectF PdfPlug::getCBox(int box, int pgNum)
 	return cRect;
 }
 
-QString PdfPlug::UnicodeParsedString(const GooString *s1)
+QString PdfPlug::UnicodeParsedString(const GooString *s1) const
 {
 #if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(25, 10, 0)
-	if (!s1 || s1->size() == 0)
+	if (!s1 || s1->empty())
 		return QString();
 	bool isUnicode;
 	int i;
@@ -1005,7 +992,7 @@ QString PdfPlug::UnicodeParsedString(const GooString *s1)
 #endif
 }
 
-QString PdfPlug::UnicodeParsedString(const std::string& s1)
+QString PdfPlug::UnicodeParsedString(const std::string& s1) const
 {
 	if (s1.length() == 0)
 		return QString();
